<#
.SYNOPSIS
   Deploys the DXA Social Connect Module for SDL Web 8 in a DXA .NET Web Application
.EXAMPLE
   .\web-install.ps1 -distDestination "c:\inetpub\wwwroot\site"
#>

[CmdletBinding( SupportsShouldProcess=$true, PositionalBinding=$false)]
Param(
    #The file system path of the root folder of your DXA Web Application
    [Parameter(Mandatory=$true, HelpMessage="The file system path of the root folder of your DXA Web Application")]
    [string]$distDestination,

    # Path of the Experience Optimization (client) log file
    [Parameter(Mandatory=$false)]
    [string]$logPath = "C:\Temp\logs\xo_client.log",

    # The log level for the Experience Optimization (client) log file
    [Parameter(Mandatory=$false)]
    [ValidateSet("Error", "Warning", "Information", "Verbose")]
    [string]$logLevel = "Warning"

)

# Terminate script on first occurred exception
$ErrorActionPreference = "Stop"

#Include functions from DxaDeployUtils.ps1
$PSScriptDir = Split-Path $MyInvocation.MyCommand.Path
. (Join-Path $PSScriptDir "..\..\..\DxaDeployUtils.ps1")

# Process 'WhatIf' and 'Confirm' options
if (!($pscmdlet.ShouldProcess($distDestination, "Deploy the DXA Social Connect Module for SDL Web 8"))) { return }

# Initialization
$distSource = Split-Path $MyInvocation.MyCommand.Path
$distSource = $distSource.TrimEnd("\")
$distDestination = $distDestination.TrimEnd("\")

Write-Host "Copying files to '$distDestination' ..."
Copy-Item $distSource\dist\* $distDestination -Recurse -Force

# Update Web.config

Write-Host "Updating Web.config ..."
[xml] $webConfigDoc = Get-Content "$distDestination\Web.config"
Add-AssemblyBinding $webConfigDoc
Enable-Social $webConfigDoc

$webConfigDoc.Save("$distDestination\Web.config")
